@@ -36,6 +36,13 @@
 #include <getopt.h>
 #endif
 
+/* At this point all Bit Types are already defined, so we must
+   protect from multiple type definition on platform where
+   __BIT_TYPES_DEFINED__ is not defined.
+ */
+#ifndef        __BIT_TYPES_DEFINED__
+#define        __BIT_TYPES_DEFINED__
+#endif
 #if defined(HAVE_DB_185_H)
 #include <db_185.h>
 #elif defined(HAVE_DB_H)
