@@ -38,7 +38,7 @@
 #include "Store.h"
 #include "ICP.h"
 #include "HttpRequest.h"
-#include "ACLChecklist.h"
+#include "acl/FilledChecklist.h"
 #include "htcp.h"
 #include "forward.h"
 #include "SquidTime.h"
@@ -290,30 +290,36 @@ peerSelectFoo(ps_state * ps)
     HttpRequest *request = ps->request;
     debugs(44, 3, "peerSelectFoo: '" << RequestMethodStr(request->method) << " " << request->GetHost() << "'");
 
+    /** If we don't known whether DIRECT is permitted ... */
     if (ps->direct == DIRECT_UNKNOWN) {
         if (ps->always_direct == 0 && Config.accessList.AlwaysDirect) {
-            ps->acl_checklist = aclChecklistCreate(
-                                    Config.accessList.AlwaysDirect,
-                                    request,
-                                    NULL);		/* ident */
-            ps->acl_checklist->nonBlockingCheck(peerCheckAlwaysDirectDone,
-                                                ps);
+            /** check always_direct; */
+            ps->acl_checklist = new ACLFilledChecklist(
+                Config.accessList.AlwaysDirect,
+                request,
+                NULL);		/* ident */
+            ps->acl_checklist->nonBlockingCheck(peerCheckAlwaysDirectDone, ps);
             return;
         } else if (ps->always_direct > 0) {
+            /** if always_direct says YES, do that. */
             ps->direct = DIRECT_YES;
         } else if (ps->never_direct == 0 && Config.accessList.NeverDirect) {
-            ps->acl_checklist = aclChecklistCreate(
-                                    Config.accessList.NeverDirect,
-                                    request,
-                                    NULL);		/* ident */
+            /** check never_direct; */
+            ps->acl_checklist = new ACLFilledChecklist(
+                Config.accessList.NeverDirect,
+                request,
+                NULL);		/* ident */
             ps->acl_checklist->nonBlockingCheck(peerCheckNeverDirectDone,
                                                 ps);
             return;
         } else if (ps->never_direct > 0) {
+            /** if always_direct says NO, do that. */
             ps->direct = DIRECT_NO;
-        } else if (request->flags.accelerated) {
+        } else if (request->flags.no_direct) {
+            /** if we are accelerating, direct is not an option. */
             ps->direct = DIRECT_NO;
         } else if (request->flags.loopdetect) {
+            /** if we are in a forwarding-loop, direct is not an option. */
             ps->direct = DIRECT_YES;
         } else if (peerCheckNetdbDirect(ps)) {
             ps->direct = DIRECT_YES;
