@@ -1,6 +1,6 @@
 
 /*
- * $Id: redirect.cc,v 1.125 2008/02/12 23:58:47 rousskov Exp $
+ * $Id$
  *
  * DEBUG: section 61    Redirector
  * AUTHOR: Duane Wessels
@@ -34,12 +34,12 @@
  */
 
 #include "squid.h"
-#include "AuthUserRequest.h"
+#include "auth/UserRequest.h"
 #include "CacheManager.h"
 #include "Store.h"
 #include "fde.h"
 #include "client_side_request.h"
-#include "ACLChecklist.h"
+#include "acl/Checklist.h"
 #include "HttpRequest.h"
 #include "client_side.h"
 #include "helper.h"
@@ -137,8 +137,8 @@ redirectStart(ClientHttpRequest * http, RH * handler, void *data)
 
     if (http->request->auth_user_request)
         r->client_ident = http->request->auth_user_request->username();
-    else if (http->request->extacl_user.buf() != NULL) {
-        r->client_ident = http->request->extacl_user.buf();
+    else if (http->request->extacl_user.defined()) {
+        r->client_ident = http->request->extacl_user.termedBuf();
     }
 
     if (!r->client_ident && (conn != NULL && conn->rfc931[0]))
